resource "aws_mq_broker" "mq_broker" {
  broker_name                = var.broker_name
  engine_type                = "ActiveMQ"
  engine_version             = var.engine_version
  host_instance_type         = var.instance_type
  security_groups            = var.security_group_ids
  subnet_ids                 = slice(var.subnet_ids, 0, 2)
  deployment_mode            = "ACTIVE_STANDBY_MULTI_AZ"
  auto_minor_version_upgrade = false
  publicly_accessible        = false

  configuration {
    id       = aws_mq_configuration.mq_configuration.id
    revision = aws_mq_configuration.mq_configuration.latest_revision
  }

  user {
    username = var.broker_username
    password = var.broker_password
    console_access = true
  }

  encryption_options {
    use_aws_owned_key = false
  }

  tags = var.tags
}

resource "aws_mq_configuration" "mq_configuration" {
  description    = "Configuration for Amazon MQ Broker"
  name           = "${var.broker_name}_configuration"
  engine_type    = "ActiveMQ"
  engine_version = var.engine_version

  data = <<DATA
<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<broker persistent="false" schedulePeriodForDestinationPurge="10000" xmlns="http://activemq.apache.org/schema/core">
  <destinationPolicy>
    <policyMap>
      <policyEntries>
        <policyEntry gcInactiveDestinations="true" inactiveTimoutBeforeGC="600000" topic="&gt;"/>
      </policyEntries>
    </policyMap>
  </destinationPolicy>
</broker>
DATA

  tags = var.tags
}